NetworkTimeout<T> class

The operation exceeded its configured timeout.

Inheritance

Constructors

NetworkTimeout({int attempts = 1, String? requestId})
Creates a NetworkTimeout result.
const

Properties

attempts int
How many attempts were made before timing out for the last time.
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
Whether this result represents success.
no setterinherited
requestId String?
The deduplication/idempotency key used for this call, if any.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueOrNull → T?
The successful value, or null for any non-NetworkSuccess result.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited