ServerUnavailableException class
Thrown when Internet is reachable but the configured server is not.
- Inheritance
-
- Object
- NetworkGuardException
- ServerUnavailableException
Constructors
-
Creates a ServerUnavailableException.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited