NetworkCancelled<T> class
The operation was cancelled before it completed — either explicitly, or because a deduplication policy replaced/cancelled it.
- Inheritance
-
- Object
- NetworkResult<
T> - NetworkCancelled
Constructors
- NetworkCancelled({String? requestId})
-
Creates a NetworkCancelled result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Whether this result represents success.
no setterinherited
- requestId → String?
-
The deduplication/idempotency key used for this call, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueOrNull → T?
-
The successful value, or
nullfor any non-NetworkSuccess result.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited